
PyDESeq2
========

.. currentmodule:: pydeseq2


.. autosummary::
    :toctree: docstrings
    :recursive:

    ~dds.DeseqDataSet
    ~ds.DeseqStats
    ~inference.Inference
    ~default_inference.DefaultInference
    ~utils
    ~grid_search
    ~preprocessing
